<?xml version="1.0" encoding="UTF-8"?>
<!-- ************************************************************************** -->
<!-- (c) Copyright IBM Corp. 2008 All rights reserved.                          -->
<!--                                                                            -->
<!-- The following sample of source code ("Sample") is owned by International   -->
<!-- Business Machines Corporation or one of its subsidiaries ("IBM") and is    -->
<!-- copyrighted and licensed, not sold. You may use, copy, modify, and         -->
<!-- distribute the Sample in any form without payment to IBM, for the purpose  -->
<!-- of assisting you in the development of your applications.                  -->
<!--                                                                            -->
<!-- The Sample code is provided to you on an "AS IS" basis, without warranty   -->
<!-- of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER         -->
<!-- EXPRESS OR  IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES -->
<!-- OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some              -->
<!-- jurisdictions do not allow for the exclusion or limitation of implied      -->
<!-- warranties, so the above limitations or exclusions may not apply to you.   -->
<!-- IBM shall not be liable for any damages you suffer as a result of using,   -->
<!-- copying, modifying or distributing the Sample, even if IBM has been        -->
<!-- advised of the possibility of such damages.                                -->
<!-- ************************************************************************** -->
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:pkg="http://www.ibm.com/xmlns/prod/db2/mon">

<xsl:output method="text"  indent="no"/>

<!-- ========================================================================== -->
<!-- Template   : Main                                                          -->
<!-- Description: Main template to process the entire XML document              -->
<!-- ========================================================================== -->
<xsl:template match="/">

<!-- ========================================================== -->
<!-- Print out each PKG Cache event in details                  -->
<!-- ========================================================== -->
  <xsl:for-each select="pkg:db2_pkgcache_event">
    <xsl:apply-templates select="." />
  </xsl:for-each>
  <xsl:text>&#10;</xsl:text>
</xsl:template>


<!-- ========================================================================== -->
<!-- Template   : Package cache event details                                   -->
<!-- Description: Template will process each db2_pkgcache_event node contained in the  -->
<!--              XML document and print out the event details.                 -->
<!-- ========================================================================== -->
<xsl:template match="pkg:db2_pkgcache_event">

  <xsl:text>&#10;</xsl:text>
  <xsl:text>&#10;</xsl:text>

  <!-- ========================================================== -->
  <!-- Print out the Event details header                         -->
  <!-- ========================================================== -->
  <xsl:text>-------------------------------------------------------&#10;</xsl:text>
  <xsl:text>Event ID               : </xsl:text>
    <xsl:value-of select="@id" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Event Type             : </xsl:text>
    <xsl:value-of select="@type" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Event Timestamp        : </xsl:text>
    <xsl:value-of select="concat(substring(@timestamp, 1, 10),
                                 '-',
                                 substring(@timestamp, 12, 2),
                                 '.',
                                 substring(@timestamp, 15, 2),
                                 '.',
                                 substring(@timestamp, 18, 9))" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Member                 : </xsl:text>
    <xsl:value-of select="@member" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Release                : </xsl:text>
    <xsl:value-of select="@release" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>-------------------------------------------------------&#10;</xsl:text>

  <!-- ========================================================== -->
  <!-- Print out the package cache details                        -->
  <!-- ========================================================== -->
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Package Cache Details&#10;</xsl:text>
  <xsl:text>---------------------&#10;</xsl:text>
  <xsl:text>Section Type                           : </xsl:text>
    <xsl:value-of select="pkg:section_type/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Insert Timestamp                       : </xsl:text>
    <xsl:value-of select="concat(substring(pkg:insert_timestamp, 1, 10),
                                 '-',
                                 substring(pkg:insert_timestamp, 12, 2),
                                 '.',
                                 substring(pkg:insert_timestamp, 15, 2),
                                 '.',
                                 substring(pkg:insert_timestamp, 18, 9))" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Executable ID                          : </xsl:text>
    <xsl:value-of select="pkg:executable_id/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Package Schema                         : </xsl:text>
    <xsl:value-of select="pkg:package_schema/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Package Name                           : </xsl:text>
    <xsl:value-of select="pkg:package_name/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Package Version ID                     : </xsl:text>
    <xsl:value-of select="pkg:package_version_id/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Section Number                         : </xsl:text>
    <xsl:value-of select="pkg:section_number/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Effective Isolation                    : </xsl:text>
    <xsl:value-of select="pkg:effective_isolation/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Number Of Executions                   : </xsl:text>
    <xsl:value-of select="pkg:num_executions/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Number Of Executions With Metrics      : </xsl:text>
    <xsl:value-of select="pkg:num_exec_with_metrics/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Prep Time                              : </xsl:text>
    <xsl:value-of select="pkg:prep_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Last Metrics Update                    : </xsl:text>
    <xsl:value-of select="concat(substring(pkg:last_metrics_update, 1, 10),
                                 '-',
                                 substring(pkg:last_metrics_update, 12, 2),
                                 '.',
                                 substring(pkg:last_metrics_update, 15, 2),
                                 '.',
                                 substring(pkg:last_metrics_update, 18, 9))" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Executions By Coordinator              : </xsl:text>
    <xsl:value-of select="pkg:num_coord_exec/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Executions By Coordinator With Metrics : </xsl:text>
    <xsl:value-of select="pkg:num_coord_exec_with_metrics/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Statement Type                         : </xsl:text>
    <xsl:value-of select="pkg:stmt_type_id/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Query Cost Estimate                    : </xsl:text>
    <xsl:value-of select="pkg:query_cost_estimate/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Statement Package Cache ID             : </xsl:text>
    <xsl:value-of select="pkg:stmt_pkg_cache_id/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Statement Text                         : </xsl:text>
    <xsl:value-of select="pkg:stmt_text/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Compilation Environment                : </xsl:text>
    <xsl:value-of select="pkg:comp_env_desc/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Section Environment                    : </xsl:text>
    <xsl:value-of select="pkg:section_env/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Routine Identifier                     : </xsl:text>
    <xsl:value-of select="pkg:routine_id/text()" />
  <xsl:text>&#10;</xsl:text>


  <!-- =================================================== -->
  <!-- Package Cache Metrics                               -->
  <!-- =================================================== -->
  <xsl:text>&#10;</xsl:text>
  <xsl:text>Metrics&#10;</xsl:text>
  <xsl:text>-------------------&#10;</xsl:text>
  <xsl:text>WLM_QUEUE_TIME_TOTAL                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:wlm_queue_time_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>WLM_QUEUE_ASSIGNMENTS_TOTAL         : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:wlm_queue_assignments_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_RECV_WAIT_TIME               : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_recv_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_RECV_WAIT_TIME          : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_recv_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_SEND_WAIT_TIME               : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_send_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_SEND_WAIT_TIME          : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_send_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOCK_WAIT_TIME                      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:lock_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOCK_WAITS                          : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:lock_waits/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIRECT_READ_TIME                    : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:direct_read_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIRECT_READ_REQS                    : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:direct_read_reqs/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIRECT_WRITE_TIME                   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:direct_write_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIRECT_WRITE_REQS                   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:direct_write_reqs/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOG_BUFFER_WAIT_TIME                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:log_buffer_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>NUM_LOG_BUFFER_FULL                 : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:num_log_buffer_full/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOG_DISK_WAIT_TIME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:log_disk_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOG_DISK_WAITS_TOTAL                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:log_disk_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_WRITE_TIME                     : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_write_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_READ_TIME                      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_read_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>AUDIT_FILE_WRITE_WAIT_TIME          : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:audit_file_write_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>AUDIT_FILE_WRITES_TOTAL             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:audit_file_writes_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>AUDIT_SUBSYSTEM_WAIT_TIME           : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:audit_subsystem_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>AUDIT_SUBSYSTEM_WAITS_TOTAL         : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:audit_subsystem_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIAGLOG_WRITE_WAIT_TIME             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:diaglog_write_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIAGLOG_WRITES_TOTAL                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:diaglog_writes_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_SEND_WAIT_TIME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_send_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_RECV_WAIT_TIME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_recv_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ACT_WAIT_TIME                 : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_act_wait_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_SECTION_SORT_PROC_TIME        : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_section_sort_proc_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_SECTION_SORTS                 : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_section_sorts/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_SECTION_SORT_TIME             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_section_sort_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ACT_TIME                      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_act_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ROUTINE_TIME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_routine_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>STMT_EXEC_TIME                      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:stmt_exec_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>COORD_STMT_EXEC_TIME                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:coord_stmt_exec_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ROUTINE_NON_SECTION_PROC_TIME : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_routine_non_sect_proc_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ROUTINE_NON_SECTION_TIME      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_routine_non_sect_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_SECTION_PROC_TIME             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_section_proc_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_SECTION_TIME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_section_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ROUTINE_USER_CODE_PROC_TIME   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_routine_user_code_proc_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ROUTINE_USER_CODE_TIME        : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_routine_user_code_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>ROWS_READ                           : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:rows_read/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>ROWS_MODIFIED                       : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:rows_modified/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_DATA_L_READS                   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_data_l_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_INDEX_L_READS                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_index_l_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_TEMP_DATA_L_READS              : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_temp_data_l_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_TEMP_INDEX_L_READS             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_temp_index_l_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_XDA_L_READS                    : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_xda_l_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_TEMP_XDA_L_READS               : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_temp_xda_l_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_CPU_TIME                      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_cpu_time/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_DATA_P_READS                   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_data_p_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_TEMP_DATA_P_READS              : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_temp_data_p_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_XDA_P_READS                    : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_xda_p_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_TEMP_XDA_P_READS               : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_temp_xda_p_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_INDEX_P_READS                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_index_p_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_TEMP_INDEX_P_READS             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_temp_index_p_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_DATA_WRITES                    : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_data_writes/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_XDA_WRITES                     : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_xda_writes/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POOL_INDEX_WRITES                   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:pool_index_writes/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIRECT_READS                        : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:direct_reads/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DIRECT_WRITES                       : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:direct_writes/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>ROWS_RETURNED                       : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:rows_returned/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>DEADLOCKS                           : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:deadlocks/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOCK_TIMEOUTS                       : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:lock_timeouts/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>LOCK_ESCALS                         : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:lock_escals/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_SENDS_TOTAL                     : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_sends_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_RECVS_TOTAL                     : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_recvs_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_SEND_VOLUME                     : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_send_volume/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_RECV_VOLUME                     : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_recv_volume/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_SENDS_TOTAL             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_sends_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_RECVS_TOTAL             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_recvs_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_SEND_VOLUME             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_send_volume/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_RECV_VOLUME             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_recv_volume/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_SENDS_TOTAL                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_sends_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_RECVS_TOTAL                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_recvs_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_SEND_VOLUME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_send_volume/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_RECV_VOLUME                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_recv_volume/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TQ_TOT_SEND_SPILLS                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:tq_tot_send_spills/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POST_THRESHOLD_SORTS                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:post_threshold_sorts/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>POST_SHRTHRESHOLD_SORTS             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:post_shrthreshold_sorts/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>SORT_OVERFLOWS                      : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:sort_overflows/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>AUDIT_EVENTS_TOTAL                  : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:audit_events_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_SORTS                         : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_sorts/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>THRESH_VIOLATIONS                   : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:thresh_violations/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>NUM_LW_THRESH_EXCEEDED              : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:num_lw_thresh_exceeded/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>TOTAL_ROUTINE_INVOCATIONS           : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:total_routine_invocations/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_RECV_WAITS_TOTAL             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_recv_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_RECV_WAITS_TOTAL        : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_recv_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_TQ_SEND_WAITS_TOTAL             : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_tq_send_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_MESSAGE_SEND_WAITS_TOTAL        : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_message_send_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_SEND_WAITS_TOTAL                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_send_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>FCM_RECV_WAITS_TOTAL                : </xsl:text>
    <xsl:value-of select="pkg:activity_metrics/pkg:fcm_recv_waits_total/text()" />
  <xsl:text>&#10;</xsl:text>




</xsl:template>

</xsl:stylesheet>
